@@ -4,6 +4,8 @@
  */
 package org.mockito.internal.verification;
 
+import java.util.List;
+
 import org.mockito.internal.InOrderImpl;
 import org.mockito.internal.invocation.finder.VerifiableInvocationsFinder;
 import org.mockito.internal.verification.api.VerificationData;
@@ -12,8 +14,6 @@ import org.mockito.internal.verification.api.VerificationInOrderMode;
 import org.mockito.invocation.Invocation;
 import org.mockito.verification.VerificationMode;
 
-import java.util.List;
-
 public class InOrderWrapper implements VerificationMode {
 
     private final VerificationInOrderMode mode;
@@ -29,9 +29,4 @@ public class InOrderWrapper implements VerificationMode {
         VerificationDataInOrderImpl dataInOrder = new VerificationDataInOrderImpl(inOrder, invocations, data.getTarget());
         mode.verifyInOrder(dataInOrder);
     }
-
-    @Override
-    public VerificationMode description(String description) {
-        return VerificationModeFactory.description(this, description);
-    }
 }
