@@ -4,11 +4,11 @@
  */
 package org.mockito.internal.reporting;
 
+import static org.junit.Assert.assertEquals;
+
 import org.junit.Test;
 import org.mockitoutil.TestBase;
 
-import static org.junit.Assert.assertEquals;
-
 public class PluralizerTest extends TestBase {
 
     @Test
@@ -25,4 +25,11 @@ public class PluralizerTest extends TestBase {
         assertEquals("was exactly 1 interaction", Pluralizer.were_exactly_x_interactions(1));
         assertEquals("were exactly 100 interactions", Pluralizer.were_exactly_x_interactions(100));
     }
+
+    @Test
+    public void pluralizes_stubbings() {
+        assertEquals("stubbings", Pluralizer.stubbings(0));
+        assertEquals("stubbing", Pluralizer.stubbings(1));
+        assertEquals("stubbings", Pluralizer.stubbings(100));
+    }
 }
