@@ -5,14 +5,16 @@
 package org.mockitousage.internal.debugging;
 
 import static org.assertj.core.api.Assertions.assertThat;
+import static org.junit.Assert.assertEquals;
+
+import java.util.ArrayList;
+import java.util.List;
 
 import org.junit.Test;
 import org.mockito.internal.debugging.LocationImpl;
 import org.mockito.internal.exceptions.stacktrace.StackTraceFilter;
 import org.mockitoutil.TestBase;
 
-import static org.junit.Assert.assertEquals;
-
 @SuppressWarnings("serial")
 public class LocationImplTest extends TestBase {
 
@@ -29,6 +31,11 @@ public class LocationImplTest extends TestBase {
             public StackTraceElement[] filter(StackTraceElement[] target, boolean keepTop) {
                 return new StackTraceElement[0];
             }
+
+            @Override
+            public StackTraceElement filterFirst(Throwable target, boolean isInline) {
+                return null;
+            }
         };
 
         //when
@@ -37,4 +44,18 @@ public class LocationImplTest extends TestBase {
         //then
         assertEquals("-> at <<unknown line>>", loc);
     }
+
+    @Test
+    public void provides_location_class() {
+        //when
+        final List<String> files = new ArrayList<String>();
+        new Runnable() { //anonymous inner class adds stress to the check
+            public void run() {
+                files.add(new LocationImpl().getSourceFile());
+            }
+        }.run();
+
+        //then
+        assertEquals("LocationImplTest.java", files.get(0));
+    }
 }
