@@ -4,6 +4,9 @@
  */
 package org.mockitousage.junitrule;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+
 import org.junit.Rule;
 import org.junit.Test;
 import org.mockito.InjectMocks;
@@ -11,14 +14,15 @@ import org.mockito.Mock;
 import org.mockito.junit.MockitoJUnit;
 import org.mockito.junit.MockitoRule;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
-
 public class MockitoJUnitRuleTest {
 
     @Rule
     public MockitoRule mockitoRule = MockitoJUnit.rule();
 
+    // Fixes #1578: Protect against multiple execution.
+    @Rule
+    public MockitoRule mockitoRule2 = mockitoRule;
+
     @Mock
     private Injected injected;
 
