@@ -4,6 +4,9 @@
  */
 package org.mockitoutil;
 
+import static java.lang.String.format;
+import static java.util.Arrays.asList;
+
 import java.io.ByteArrayInputStream;
 import java.io.File;
 import java.io.IOException;
@@ -32,13 +35,11 @@ import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
 import java.util.concurrent.Future;
 import java.util.concurrent.ThreadFactory;
+
 import org.objenesis.Objenesis;
 import org.objenesis.ObjenesisStd;
 import org.objenesis.instantiator.ObjectInstantiator;
 
-import static java.lang.String.format;
-import static java.util.Arrays.asList;
-
 public abstract class ClassLoaders {
     protected ClassLoader parent = currentClassLoader();
 
@@ -474,6 +475,11 @@ public abstract class ClassLoaders {
                     addFromFileBasedClassLoader(classes, uri);
                 } else if (uri.getScheme().equalsIgnoreCase(InMemoryClassLoader.SCHEME)) {
                     addFromInMemoryBasedClassLoader(classes, uri);
+                } else if (uri.getScheme().equalsIgnoreCase("jar")) {
+                    // Java 9+ returns "jar:file:" style urls for modules.
+                    // It's not a classes owned by mockito itself.
+                    // Just ignore it.
+                    continue;
                 } else {
                     throw new IllegalArgumentException(format("Given ClassLoader '%s' don't have reachable by File or vi ClassLoaders.inMemory", classLoader));
                 }
